@@ -4,8 +4,8 @@ __author__ = ('Aitor Blanco Miguez (aitor.blancomiguez@unitn.it), '
               'Francesco Asnicar (f.asnicar@unitn.it), '
               'Moreno Zolfo (moreno.zolfo@unitn.it), '
               'Francesco Beghini (francesco.beghini@unitn.it)')
-__version__ = '3.0.8'
-__date__ = '7 May 2021'
+__version__ = '3.0.10'
+__date__ = '14 Jun 2021'
 
 
 import sys
@@ -68,15 +68,17 @@ def read_params():
                     help="Threshold defining the minimun number of markers to keep a sample")
     p.add_argument('--secondary_sample_with_n_markers', type=int, default=20,
                     help="Threshold defining the minimun number of markers to keep a secondary sample")
-    p.add_argument('--phylophlan_mode', choices=PHYLOPHLAN_MODES, default='accurate',
+    p.add_argument('--phylophlan_mode', choices=PHYLOPHLAN_MODES, default='fast',
                     help="The presets for fast or accurate phylogenetic analysis")
     p.add_argument('--phylophlan_configuration', type=str, default=None,
                     help="The PhyloPhlAn configuration file")
     p.add_argument('--mutation_rates', action='store_true', default=False,
-                   help=("If specified will produced a mutation rates table for each of the aligned markers and a summary table "
+                   help=("If specified, StrainPhlAn will produce a mutation rates table for each of the aligned markers and a summary table "
                          "for the concatenated MSA. This operation can take long time to finish"))
     p.add_argument('--print_clades_only', action='store_true', default=False,
-                   help=("If specified only print the potential clades and stop without building any tree"))
+                   help=("If specified, StrainPhlAn will only print the potential clades and stop the execution"))
+    p.add_argument('--debug', action='store_true', default=False,
+                   help=("If specified, StrainPhlAn will not remove the temporal folders"))
     
     return p.parse_args()
 
@@ -396,7 +398,7 @@ def sample_markers_to_fasta(sample_path, filtered_samples, tmp_dir, filtered_cla
             for r in sample:
                 if r['marker'] in filtered_clade_markers:
                     marker_name = parse_marker_name(r['marker'])
-                    seq = SeqRecord(Seq(r['sequence'][trim_sequences:-trim_sequences].replace("*","N").replace("-","N")), id=marker_name, description=marker_name)
+                    seq = SeqRecord(Seq(r['sequence'][trim_sequences:-trim_sequences].replace("*","N").replace("-","N").strip('N')), id=marker_name, description=marker_name)
                     SeqIO.write(seq, marker_fna, 'fasta')
 
 
@@ -736,12 +738,13 @@ Executes StrainPhlAn
 :param phylophlan_configuration: the PhyloPhlAn configuration file
 :param mutation_rates: whether get  the mutation rates for the markers
 :param print_clades_only: whether print only the potential clades and stop
+:param debug: wether to save the tmp folders
 :param nprocs: the threads used for execution
 """
 def strainphlan(database, clade_markers, samples, references, secondary_samples, 
     secondary_references, clade, output_dir, trim_sequences, samples_with_n_markers, 
     marker_in_n_samples, secondary_samples_with_n_markers, phylophlan_mode, 
-    phylophlan_configuration, mutation_rates, print_clades_only, nprocs):
+    phylophlan_configuration, mutation_rates, print_clades_only, debug, nprocs):
     if print_clades_only:
         print_clades(database, samples, samples_with_n_markers, marker_in_n_samples)
     else:
@@ -786,9 +789,10 @@ def strainphlan(database, clade_markers, samples, references, secondary_samples,
             samples_with_n_markers, marker_in_n_samples, secondary_samples_with_n_markers, 
             phylophlan_mode, nprocs)
         info("Done.", init_new_line=True)
-        info("Removing temporary files...", init_new_line=True)
-        rmtree(tmp_dir, ignore_errors=False, onerror=None)
-        info("Done.", init_new_line=True)
+        if not debug:
+            info("Removing temporary files...", init_new_line=True)
+            rmtree(tmp_dir, ignore_errors=False, onerror=None)
+            info("Done.", init_new_line=True)
 
 
 """
@@ -813,6 +817,7 @@ Main function
 :param phylophlan_configuration: the PhyloPhlAn configuration file
 :param mutation_rates: whether get  the mutation rates for the markers
 :param print_clades_only: whether print only the potential clades and stop
+:param debug: wether to save the tmp folders
 :param nprocs: the threads used for execution
 """
 def main():
@@ -824,7 +829,7 @@ def main():
         args.secondary_samples, args.secondary_references,  args.clade, args.output_dir, 
         args.trim_sequences, args.sample_with_n_markers, args.marker_in_n_samples,
         args.secondary_sample_with_n_markers, args.phylophlan_mode, args.phylophlan_configuration, 
-        args.mutation_rates, args.print_clades_only, args.nprocs)
+        args.mutation_rates, args.print_clades_only, args.debug, args.nprocs)
     exec_time = time.time() - t0
     if not args.print_clades_only:
         info("Finish StrainPhlAn " + __version__ + " execution ("+str(round(exec_time, 2))+
